﻿using ProjectSeaplane.CollectionGenericObjects;
using ProjectSeaplane.Drawings;
using System.Windows.Forms;

namespace ProjectSeaplane;

public partial class FormSeaplaneCollection : Form
{
    private AbstractCompany? _company = null;

    public FormSeaplaneCollection()
    {
        InitializeComponent();
    }

    private void ComboBoxSelectorCompany_SelectedIndexChanged(object sender, EventArgs e)
    {
        switch (comboBoxSelectorCompany.Text)
        {
            case "Хранилище":
                _company = new PlaneSharingService(pictureBox.Width, pictureBox.Height, new MassiveGenericObjects<DrawingPlane>());
                break;
        }
    }

    private void ButtonAddPlane_Click(object sender, EventArgs e) => CreateObject(nameof(DrawingPlane));

    private void ButtonAddSeaplane_Click(object sender, EventArgs e) => CreateObject(nameof(DrawingSeaplane));

    private void CreateObject(string type)
    {
        if (_company == null)
        {
            return;
        }

        Random random = new();
        DrawingPlane drawningPlane;
        switch (type)
        {
            case nameof(DrawingPlane):
                drawningPlane = new DrawingPlane(random.Next(100, 300), random.Next(1000, 3000), GetColor(random));
                break;
            case nameof(DrawingSeaplane):
                drawningPlane = new DrawingSeaplane(random.Next(100, 300), random.Next(1000, 3000), 
                    GetColor(random), GetColor(random),
                    Convert.ToBoolean(random.Next(0, 2)), Convert.ToBoolean(random.Next(0, 2)));
                break;
            default:
                return;
        }

        if (_company + drawningPlane != -1)
        {
            MessageBox.Show("Объект добавлен");
            pictureBox.Image = _company.Show();
        }
        else
        {
            MessageBox.Show("Не удалось добавить объект");
        }
    }

    private static Color GetColor(Random random)
    {
        Color color = Color.FromArgb(random.Next(0, 256), random.Next(0, 256), random.Next(0, 256));
        ColorDialog dialog = new();
        if (dialog.ShowDialog() == DialogResult.OK)
        {
            color = dialog.Color;
        }

        return color;
    }

    private void buttonDelPlane_Click(object sender, EventArgs e)
    {
        if (string.IsNullOrEmpty(maskedTextBoxPosition.Text) || _company == null)
        {
            return;
        }

        if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) != DialogResult.Yes)
        {
            return;
        }

        int pos = Convert.ToInt32(maskedTextBoxPosition.Text);
        if (_company - pos != null)
        {
            MessageBox.Show("Объект удален");
            pictureBox.Image = _company.Show();
        }
        else
        {
            MessageBox.Show("Не удалось удалить объект");
        }
    }

    private void buttonGoToCheck_Click(object sender, EventArgs e)
    {
        if (_company == null)
        {
            return;
        }

        DrawingPlane? plane = null;
        int counter = 100;
        while (plane == null)
        {
            plane = _company.GetRandomObject();
            counter--;
            if (counter <= 0)
            {
                break;
            }
        }

        if (plane == null)
        {
            return;
        }

        FormSeaplane form = new()
        {
            SetPlane = plane
        };
        form.ShowDialog();
    }

    private void buttonRefresh_Click(object sender, EventArgs e)
    {
        if (_company == null)
        {
            return;
        }

        pictureBox.Image = _company.Show();
    }
}
